#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-9l0Xn8RQH2K7GgMCagaeTr
key:                  lsp-2.2.0.0-9l0Xn8RQH2K7GgMCagaeTr
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  a0f5fd954a16d2b17ee8e84e30f508c0
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-FIx3Ezdh8PjBHNPfNHKxz7:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-FIx3Ezdh8PjBHNPfNHKxz7:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-FIx3Ezdh8PjBHNPfNHKxz7:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-FIx3Ezdh8PjBHNPfNHKxz7:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-9l0Xn8RQH2K7GgMCagaeTr
depends:
    aeson-2.2.2.0-Bvq1RZLTB982HJyF7e96XU
    async-2.2.6-L49doqolqOiLsPy3OvdI1h
    attoparsec-0.14.4-9CcJCC4ORykBmnSiMZ6uwP base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-39Wv1c0c3NEAmuSWUqUwqo
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-LB47rq9amzm4H74gyqVlYy
    lens-5.3.4-4VhpdbpDp0x9CLN9dxQmc7
    lens-aeson-1.2.3-FqT8XoTlMtx6waVVY3vUkT
    lsp-types-2.0.2.0-FIx3Ezdh8PjBHNPfNHKxz7 mtl-2.3.1
    prettyprinter-1.7.1-3tqZuvkzaQgKArc0IOnBsn
    random-1.2.1.3-5FoUrrA3875KkJXWnCWBBA
    row-types-1.0.1.2-BkErSaw2LbQLGr6ixVl7AO
    sorted-list-0.2.3.1-3rvBSBXtWHFG8aJa0F2Wom stm-2.5.1.0
    temporary-1.3-A3KjuMYmCbV2j39Y1k6FK6 text-2.0.2
    text-rope-0.3-3hVOhF4Ry2F5957kYxdbl6 transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-ITIVaOGw28dDFkmcPJu0s3
    uuid-1.3.16.1-2FavIqrolec41NAkrHXRfw

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

